@@ -102,14 +102,20 @@ QImage * Target::getPictureSmall () {
 	return pictureSmall;
 }
 QImage * Target::getPicture () {
+	return getPicture (::dbManager);
+}
+QImage * Target::getPictureBack () {
+	return getPictureBack (::dbManager);
+}
+QImage * Target::getPicture (DatabaseManager * mgr) {
 	if(!picture) {
-		picture = ::dbManager->getPicture (this);
+		picture = mgr->getPicture (this);
 	}
 	return picture;
 }
-QImage * Target::getPictureBack () {
+QImage * Target::getPictureBack (DatabaseManager * mgr) {
 	if(!pictureBack) {
-		pictureBack = ::dbManager->getPictureBack (this);
+		pictureBack = mgr->getPictureBack (this);
 	}
 	return pictureBack;
 }
@@ -289,26 +295,27 @@ bool DatabaseManager::migrationFrom (DatabaseManager * mgr) {
 	for (int i = 0; i < list.size (); i++) {
 		Target * target = list[i];
 
-		//qDebug () << "MIGRATING " << target->name;
+		//qDebug () << "MIGRATING " << target->name << " " << target->id;
 
 		mgr->getFields(target);
+		target->getPicture(mgr);
+		target->getPictureBack(mgr);
+		res = copyTarget(target);
 
-		res = insertTarget(target);
-
-		//qDebug () << "MIGRATING 1 " << target->name << res;
+		//qDebug () << "MIGRATING 1 " << target->name << res << " " << target->id;
 		if (!res) return false;
 
-		if (target->getPicture() != NULL) {
-			res = updateTargetPicture (target);
-			//qDebug () << "MIGRATING 2 " << target->name << res;
-			if (!res) return false;
-		}
-
-		if (target->getPictureBack() != NULL) {
-			res = updateTargetPictureBack (target);
-			//qDebug () << "MIGRATING 3 " << target->name << res;
-			if (!res) return false;
-		}
+//		if (target->getPicture(mgr) != NULL) {
+//			res = updateTargetPicture (target);
+//			//qDebug () << "MIGRATING 2 " << target->name << res;
+//			if (!res) return false;
+//		}
+//
+//		if (target->getPictureBack(mgr) != NULL) {
+//			res = updateTargetPictureBack (target);
+//			//qDebug () << "MIGRATING 3 " << target->name << res;
+//			if (!res) return false;
+//		}
 
 		res = updateFields (target);
 		//qDebug () << "MIGRATING 4 " << target->name << res;
@@ -873,6 +880,57 @@ bool DatabaseManager::insertTarget(Target* target)
 	return ret;
 }
 
+bool DatabaseManager::copyTarget(Target* target)
+{
+		//qDebug() << "step 0" ;
+
+	bool ret = false;
+	if (db.isOpen()) {
+		QSqlQuery query (db);
+		ret = query.prepare("INSERT INTO targets (id, name, type, picture, pictureBack, groupName) VALUES (:id, :name, :type, :picture, :pictureBack, :groupName)");
+		QByteArray t1;
+
+		if (ret) {
+			encrypt(target->name, t1);
+			query.bindValue(":id", target->id);
+			query.bindValue(":name", t1);
+			query.bindValue(":type", target->type);
+			query.bindValue(":groupName", target->groupName);
+					//qDebug() << "step 4" ;
+
+			QByteArray im1;
+			QBuffer buffer1(&im1);
+			QByteArray im_r1;
+			QByteArray im2;
+			QBuffer buffer2(&im2);
+			QByteArray im_r2;
+
+			if (target->picture != NULL) {
+				buffer1.open(QIODevice::WriteOnly);
+				target->picture->save(&buffer1, "PNG"); // writes image into ba in PNG format
+
+				encrypt(im1, im_r1);
+				query.bindValue(":picture", im_r1);
+			} else
+				query.bindValue(":picture", QVariant (QVariant::ByteArray));
+
+			if (target->pictureBack != NULL) {
+				buffer2.open(QIODevice::WriteOnly);
+				target->pictureBack->save(&buffer2, "PNG"); // writes image into ba in PNG format
+
+				QByteArray im_r2;
+				encrypt(im2, im_r2);
+				query.bindValue(":pictureBack", im_r2);
+			} else
+				query.bindValue(":pictureBack", QVariant (QVariant::ByteArray));
+						//qDebug() << "step 7" ;
+
+			ret = query.exec();
+		}
+	}
+	return ret;
+}
+
 QList<Target*> DatabaseManager::getTargets(const QString * filter)
 {
 	QList<Target*> result;
@@ -955,13 +1013,14 @@ bool DatabaseManager::updateFields(Target* target)
 		query.bindValue(":code", target->id);
 		ret = query.exec();
 
+		if (ret)
 		for (int i = 0; i < target->fields.count(); i++) {
 			TargetField * field = target->fields[i];
 	
 //			if (field->id == -1) {
 				field->targetId = target->id;
 				field->id = 0;
-				ret |= insertTargetField (field);
+				ret &= insertTargetField (field);
 //			}
 //			else {
 //				ret |= updateTargetField (field);
@@ -972,6 +1031,17 @@ bool DatabaseManager::updateFields(Target* target)
 	return ret;
 }
 
+bool DatabaseManager::copyFields(Target* target)
+{
+	bool ret = true;
+	for (int i = 0; i < target->fields.count(); i++) {
+		TargetField * field = target->fields[i];
+		ret &= copyTargetField (field);
+	}
+
+	return ret;
+}
+
 bool DatabaseManager::updateTarget(Target* target)
 {
 	bool ret = false;
@@ -1136,6 +1206,38 @@ bool DatabaseManager::insertTargetField(TargetField* field)
 	return ret;
 }
 
+bool DatabaseManager::copyTargetField(TargetField* field)
+{
+	bool ret = false;
+	if (db.isOpen()) {
+		QSqlQuery query (db);
+		ret = query.prepare("INSERT INTO fields (id, targetId, name, value, type, orderN, encrypted) "
+		                    "VALUES (:id, :targetId, :name, :value, :type, :order, :encrypted)");
+		if (ret) {
+			query.bindValue(":id", field->id);
+			query.bindValue(":targetId", field->targetId);
+
+			if (field->encrypted) {
+				QByteArray a, b;
+				encrypt(field->name, a);
+				encrypt(field->value, b);
+				query.bindValue(":name", a);
+				query.bindValue(":value", b);
+			}
+			else {
+				query.bindValue(":name", field->name);
+				query.bindValue(":value", field->value);
+			}
+			query.bindValue(":type", field->type);
+			query.bindValue(":order", field->order);
+			query.bindValue(":encrypted", field->encrypted ? 1 : 0);
+			ret = query.exec();
+		}
+
+	}
+	return ret;
+}
+
 void DatabaseManager::getFields(Target * target)
 {
 	if (target->listLoaded) return;
