@@ -8,7 +8,8 @@
 #include <Qt>
 #include <QDesktopServices>
 //#include <QtXml>
-//#include <QXmlSimpleReader>
+
+#include "camera.h"
 
 class QLabelW: public QLabel {
 
@@ -118,6 +119,9 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 		menuBar()->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
 		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
 		menuBar()->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
+
+		menuBar()->addAction(tr("Camera"), this, SLOT(takePicture()));
+
 		//TODO menuBar()->addAction("Delete field", this, SLOT(addNewField()));
 		//TODO menuBar()->addAction("Modify field", this, SLOT(addNewField()));
 	}
@@ -327,6 +331,12 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 	vboxlayout->addLayout(componentLayout);
 
+	if (edit) {
+		QPushButton * saveButton = new QPushButton (tr("Save"), this);
+		vboxlayout->addWidget(saveButton);
+		QObject::connect(saveButton, SIGNAL(clicked()), this, SLOT(saveTarget()));
+	}
+
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
 	orientationChanged(0);
@@ -979,6 +989,22 @@ void DetailWindow::cardBack()
 	}
 }
 
+void DetailWindow::photoTake (QImage* image) {
+	if (currentImageBackN) delete currentImageBackN;
+
+	currentImageBackN = new QImage (*image);
+
+	imageBackLabel->setPixmap(QPixmap::fromImage (*currentImageBackN));
+
+	deleteBack = false;
+}
+
+void DetailWindow::takePicture () {
+	QCamera * cam = new QCamera;
+
+	connect (cam, SIGNAL(photoReady (QImage*)), this, SLOT(photoTake(QImage*)));
+}
+
 void DetailWindow::closeEvent(QCloseEvent *event) {
 	//qDebug () << "close event";
 	if ((!forceClose) && (edit || isNew)) {
