@@ -105,6 +105,10 @@ public slots:
 	void _editTarget();
 	void _newTarget();
 
+	void takePicture();
+	void photoTake (QImage* image);
+
+
 	void _newLikeTarget();
 	void _duplicateTarget();
 
