@@ -218,7 +218,11 @@ LoginDialog::~LoginDialog()
 }
 void LoginDialog::about()
 {
-    QMessageBox::about(this, tr("About Wallet"), tr(TEXT_ABOUT));
+    QMessageBox::about(this, tr("About Wallet"), tr("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
+			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
+			"<p>Icons by http://pixelmixer.ru/</p>"\
+			"<p>if you think that qtWallet is useful for you, please</p>"\
+			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>"));
 }
 void LoginDialog::donate() {
 	QDesktopServices::openUrl( QUrl::fromEncoded("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted" ) );
