@@ -36,8 +36,8 @@ class eWallet: public QMainWindow
 	Q_OBJECT
 
 public:
-	eWallet (QWidget *parent = 0);
-	eWallet (QString group, eWallet *_parent, QWidget *parent = 0);
+	eWallet (QWidget * parent = 0);
+	eWallet (QString * group, eWallet *_parent, QWidget *parent = 0);
 	~eWallet ();
 
 	bool finalPassword (const QString & pas);
@@ -76,7 +76,7 @@ private:
 	void createMenu();
 	void showGroups(bool reset);
 	void showInfo(bool reset);
-	void showTargets(bool reset, const QString & filter);
+	void showTargets(bool reset, const QString * filter);
 	void loadTypesAndFields ();
 	void filterBy (const QString & s);
 	QPixmap getImage (Target * f);
@@ -140,7 +140,7 @@ private:
 	bool ascSort;
 	int isShowGroups;
 	QString currentFilter;
-	QString currentGroup;
+	QString * currentGroup;
 };
 
 
