@@ -11,6 +11,8 @@
 
 int main(int argc, char *argv[])
 {
+	QCoreApplication::setAttribute(Qt::AA_NativeWindows);
+
     QApplication app(argc, argv);
 
     QString lang;
@@ -21,6 +23,8 @@ int main(int argc, char *argv[])
     else
     	lang = QLocale::system().name();
 
+    qDebug () << " SYST = " << QLibraryInfo::location(QLibraryInfo::TranslationsPath) << " IN " << lang;
+
     QTranslator qtTranslator;
     qtTranslator.load(QString("qt_") + lang,
             QLibraryInfo::location(QLibraryInfo::TranslationsPath));
