@@ -4,52 +4,52 @@
 <context>
     <name>CreateFieldDialog</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1049"/>
+        <location filename="../../DetailedWindow.cpp" line="1118"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1062"/>
+        <location filename="../../DetailedWindow.cpp" line="1131"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1072"/>
+        <location filename="../../DetailedWindow.cpp" line="1141"/>
         <source>String</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1073"/>
+        <location filename="../../DetailedWindow.cpp" line="1142"/>
         <source>Text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1074"/>
+        <location filename="../../DetailedWindow.cpp" line="1143"/>
         <source>Date</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1075"/>
+        <location filename="../../DetailedWindow.cpp" line="1144"/>
         <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1076"/>
+        <location filename="../../DetailedWindow.cpp" line="1145"/>
         <source>Phone Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1077"/>
+        <location filename="../../DetailedWindow.cpp" line="1146"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1078"/>
+        <location filename="../../DetailedWindow.cpp" line="1147"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="1083"/>
+        <location filename="../../DetailedWindow.cpp" line="1152"/>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
@@ -57,259 +57,265 @@
 <context>
     <name>DetailWindow</name>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="63"/>
+        <location filename="../../DetailedWindow.cpp" line="65"/>
         <source>Copy of </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="110"/>
+        <location filename="../../DetailedWindow.cpp" line="112"/>
+        <location filename="../../DetailedWindow.cpp" line="335"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="112"/>
-        <location filename="../../DetailedWindow.cpp" line="739"/>
-        <location filename="../../DetailedWindow.cpp" line="752"/>
+        <location filename="../../DetailedWindow.cpp" line="114"/>
+        <location filename="../../DetailedWindow.cpp" line="781"/>
+        <location filename="../../DetailedWindow.cpp" line="794"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="113"/>
+        <location filename="../../DetailedWindow.cpp" line="115"/>
         <source>Change Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="114"/>
+        <location filename="../../DetailedWindow.cpp" line="116"/>
         <source>Mirror Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="115"/>
+        <location filename="../../DetailedWindow.cpp" line="117"/>
         <source>Change Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="116"/>
+        <location filename="../../DetailedWindow.cpp" line="118"/>
         <source>Mirror Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="117"/>
+        <location filename="../../DetailedWindow.cpp" line="119"/>
         <source>Delete Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="118"/>
+        <location filename="../../DetailedWindow.cpp" line="120"/>
         <source>Delete Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="119"/>
+        <location filename="../../DetailedWindow.cpp" line="121"/>
         <source>Modify fields</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="124"/>
-        <source>New Card</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../DetailedWindow.cpp" line="125"/>
-        <source>Edit Card</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../DetailedWindow.cpp" line="126"/>
-        <source>New Card like this</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../DetailedWindow.cpp" line="127"/>
-        <source>Duplicate Card</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../DetailedWindow.cpp" line="128"/>
-        <source>Export Face Pict.</source>
+        <location filename="../../DetailedWindow.cpp" line="123"/>
+        <source>Camera</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="129"/>
+        <source>New Card</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../DetailedWindow.cpp" line="130"/>
+        <source>Edit Card</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../DetailedWindow.cpp" line="131"/>
+        <source>New Card like this</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../DetailedWindow.cpp" line="132"/>
+        <source>Duplicate Card</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../DetailedWindow.cpp" line="133"/>
+        <source>Export Face Pict.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../DetailedWindow.cpp" line="134"/>
         <source>Export Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="156"/>
+        <location filename="../../DetailedWindow.cpp" line="161"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="167"/>
+        <location filename="../../DetailedWindow.cpp" line="172"/>
         <source>Group Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="185"/>
+        <location filename="../../DetailedWindow.cpp" line="190"/>
         <source>Membership Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="186"/>
+        <location filename="../../DetailedWindow.cpp" line="191"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="187"/>
+        <location filename="../../DetailedWindow.cpp" line="192"/>
         <source>Credit Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="188"/>
+        <location filename="../../DetailedWindow.cpp" line="193"/>
         <source>Bank Account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="189"/>
+        <location filename="../../DetailedWindow.cpp" line="194"/>
         <source>Health Numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="190"/>
+        <location filename="../../DetailedWindow.cpp" line="195"/>
         <source>Passport Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="191"/>
+        <location filename="../../DetailedWindow.cpp" line="196"/>
         <source>Note Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="192"/>
+        <location filename="../../DetailedWindow.cpp" line="197"/>
         <source>Car Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="193"/>
+        <location filename="../../DetailedWindow.cpp" line="198"/>
         <source>Cellular Phone</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="194"/>
+        <location filename="../../DetailedWindow.cpp" line="199"/>
         <source>Serial Number Software</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="195"/>
+        <location filename="../../DetailedWindow.cpp" line="200"/>
         <source>Serial Number Hardware</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="196"/>
+        <location filename="../../DetailedWindow.cpp" line="201"/>
         <source>Web site</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="197"/>
+        <location filename="../../DetailedWindow.cpp" line="202"/>
         <source>ID Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="198"/>
+        <location filename="../../DetailedWindow.cpp" line="203"/>
         <source>Social Security Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="199"/>
+        <location filename="../../DetailedWindow.cpp" line="204"/>
         <source>Email Account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="200"/>
+        <location filename="../../DetailedWindow.cpp" line="205"/>
         <source>Driver&apos;s License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="201"/>
+        <location filename="../../DetailedWindow.cpp" line="206"/>
         <source>Others</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="205"/>
+        <location filename="../../DetailedWindow.cpp" line="210"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="473"/>
-        <location filename="../../DetailedWindow.cpp" line="519"/>
+        <location filename="../../DetailedWindow.cpp" line="516"/>
+        <location filename="../../DetailedWindow.cpp" line="562"/>
         <source>Click to see</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="573"/>
+        <location filename="../../DetailedWindow.cpp" line="615"/>
         <source>Card description is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="583"/>
+        <location filename="../../DetailedWindow.cpp" line="625"/>
         <source>Type card is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="737"/>
-        <location filename="../../DetailedWindow.cpp" line="750"/>
+        <location filename="../../DetailedWindow.cpp" line="779"/>
+        <location filename="../../DetailedWindow.cpp" line="792"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="738"/>
-        <location filename="../../DetailedWindow.cpp" line="751"/>
+        <location filename="../../DetailedWindow.cpp" line="780"/>
+        <location filename="../../DetailedWindow.cpp" line="793"/>
         <source>Mirror</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="742"/>
+        <location filename="../../DetailedWindow.cpp" line="784"/>
         <source>Export Face</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="755"/>
+        <location filename="../../DetailedWindow.cpp" line="797"/>
         <source>Export Back</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="773"/>
+        <location filename="../../DetailedWindow.cpp" line="818"/>
         <source>Choose card face image file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="775"/>
-        <location filename="../../DetailedWindow.cpp" line="913"/>
+        <location filename="../../DetailedWindow.cpp" line="820"/>
+        <location filename="../../DetailedWindow.cpp" line="962"/>
         <source>Images (*.png);;</source>
         <translation>Images PNG (*.png)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="787"/>
+        <location filename="../../DetailedWindow.cpp" line="833"/>
         <source>Choose card face image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="789"/>
-        <location filename="../../DetailedWindow.cpp" line="928"/>
+        <location filename="../../DetailedWindow.cpp" line="835"/>
+        <location filename="../../DetailedWindow.cpp" line="978"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
         <translation>Images (*.png *.jpg *.gif *.jpeg)</translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="911"/>
+        <location filename="../../DetailedWindow.cpp" line="960"/>
         <source>Choose card back image file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="926"/>
+        <location filename="../../DetailedWindow.cpp" line="976"/>
         <source>Choose card back image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../DetailedWindow.cpp" line="966"/>
+        <location filename="../../DetailedWindow.cpp" line="1028"/>
         <source>Are you sure you want to discard changes?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -347,17 +353,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="239"/>
+        <location filename="../../LoginDialog.cpp" line="221"/>
+        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../LoginDialog.cpp" line="243"/>
         <source>Password is required</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="256"/>
+        <location filename="../../LoginDialog.cpp" line="260"/>
         <source>For verification, please, enter your password again</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../LoginDialog.cpp" line="269"/>
+        <location filename="../../LoginDialog.cpp" line="273"/>
         <source>Invalid password, please enter again</source>
         <translation type="unfinished"></translation>
     </message>
@@ -389,13 +400,13 @@
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="366"/>
-        <location filename="../../eWallet.cpp" line="819"/>
+        <location filename="../../eWallet.cpp" line="818"/>
         <source>&lt;All&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="385"/>
-        <location filename="../../eWallet.cpp" line="828"/>
+        <location filename="../../eWallet.cpp" line="827"/>
         <source>&lt;No Group&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -748,116 +759,121 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="908"/>
+        <location filename="../../eWallet.cpp" line="907"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="910"/>
+        <location filename="../../eWallet.cpp" line="909"/>
         <source>Delete DB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="912"/>
-        <location filename="../../eWallet.cpp" line="923"/>
+        <location filename="../../eWallet.cpp" line="911"/>
+        <location filename="../../eWallet.cpp" line="922"/>
         <source>Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="915"/>
+        <location filename="../../eWallet.cpp" line="914"/>
         <source>New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="917"/>
-        <location filename="../../eWallet.cpp" line="1391"/>
+        <location filename="../../eWallet.cpp" line="916"/>
+        <location filename="../../eWallet.cpp" line="1390"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="918"/>
+        <location filename="../../eWallet.cpp" line="917"/>
         <source>Invert Sort</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="919"/>
+        <location filename="../../eWallet.cpp" line="918"/>
         <source>Import</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="920"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Export</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="922"/>
+        <location filename="../../eWallet.cpp" line="921"/>
         <source>Change Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="982"/>
+        <location filename="../../eWallet.cpp" line="981"/>
         <source>Are you sure you want to remove it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1130"/>
+        <location filename="../../eWallet.cpp" line="1129"/>
         <source>Choose import file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1132"/>
-        <location filename="../../eWallet.cpp" line="1407"/>
+        <location filename="../../eWallet.cpp" line="1131"/>
+        <location filename="../../eWallet.cpp" line="1409"/>
         <source>Text files (*.txt);;</source>
         <translation>Text files (*.txt)</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1380"/>
+        <location filename="../../eWallet.cpp" line="1379"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1381"/>
-        <location filename="../../eWallet.cpp" line="1394"/>
+        <location filename="../../eWallet.cpp" line="1380"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1390"/>
+        <location filename="../../eWallet.cpp" line="1389"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1392"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>New like this</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1393"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>Duplicate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1405"/>
+        <location filename="../../eWallet.cpp" line="1407"/>
         <source>Choose export file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1610"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
         <source>About Wallet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1645"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
+        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="1654"/>
         <source>Changing password, please wait until application quits</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1651"/>
+        <location filename="../../eWallet.cpp" line="1660"/>
         <source>Password changed successfully, application will exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1653"/>
+        <location filename="../../eWallet.cpp" line="1662"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation type="unfinished"></translation>
     </message>
